@@ -31,6 +31,7 @@
 #include <apr_thread_cond.h>
 #include <httpd.h>
 #include <http_request.h>
+#include <http_core.h>
 #include <util_filter.h>
 #include <http_config.h>
 #include <http_log.h>
@@ -288,8 +289,11 @@ upload_filter_compatphp(ap_filter_t *f, apr_bucket_brigade *bb_in,
 
   res = ap_get_brigade(f->next, bb_in, mode, block, nbytes);
   if (res != APR_SUCCESS) {
-    ap_log_rerror(APLOG_MARK,APLOG_ERR, res, f->r, "ap_get_brigade failed");
-    return res;
+    ap_log_rerror(APLOG_MARK,APLOG_ERR, res, f->r,
+		  "ap_get_brigade failed in %s. Possible cause is "
+		  "LimitRequestBody = %d", __func__,
+		  ap_get_limit_req_body(f->r));
+    goto out;
   }
 
   note = (upload_note_t *)apr_table_get(r->notes, "mod_upload");
@@ -1145,7 +1149,10 @@ upload_filter(ap_filter_t *f, apr_bucket_brigade *bb_in,
 
   res = ap_get_brigade(f->next, bb_in, mode, block, nbytes);
   if (res != APR_SUCCESS) {
-    ap_log_rerror(APLOG_MARK,APLOG_ERR, res, f->r, "ap_get_brigade failed");
+    ap_log_rerror(APLOG_MARK,APLOG_ERR, res, f->r,
+		  "ap_get_brigade failed in %s. Possible cause is "
+		  "LimitRequestBody = %d", __func__,
+		  ap_get_limit_req_body(f->r));
     goto out;
   }
 
